@@ -118,11 +118,11 @@ def is_child_of_process_name(processname, pid=None):
         with open(stat_file) as stat_f:
             stat = stat_f.read()
         # extract command (inside ())
-        command = stat.partition("(")[2].partition(")")[0]
+        command = stat.partition("(")[2].rpartition(")")[0]
         if command == processname:
             return True
         # get parent (second to the right of command) and check that next
-        pid = int(stat.partition(")")[2].split()[1])
+        pid = int(stat.rpartition(")")[2].split()[1])
     return False
 
 
