@@ -64,7 +64,7 @@ class InstallBackendAptdaemon(InstallBackend, BuilderDialog):
         try:
             trans = yield self.client.update_cache(defer=True)
             yield self._show_transaction(trans, self.ACTION_UPDATE,
-                                         _("Checking for updates…"),  False)
+                                         _("Checking for updates…"), False)
         except errors.NotAuthorizedError:
             self._action_done(self.ACTION_UPDATE,
                               authorized=False, success=False,
@@ -235,6 +235,13 @@ class InstallBackendAptdaemon(InstallBackend, BuilderDialog):
 
 
 if __name__ == "__main__":
-    b = InstallBackendAptdaemon(None)
-    b.commit(["2vcard"], [], False)
+    import mock
+    options = mock.Mock()
+    data_dir = "/usr/share/update-manager"
+
+    from UpdateManager.UpdateManager import UpdateManager
+    app = UpdateManager(data_dir, options)
+
+    b = InstallBackendAptdaemon(app, None)
+    b.commit(["2vcard"], [])
     Gtk.main()
