@@ -31,7 +31,8 @@ class TestUtils(unittest.TestCase):
         self.assertTrue(estimate > 0)
 
     def test_is_child_of_process_name(self):
-        self.assertTrue(utils.is_child_of_process_name("init"))
+        self.assertTrue(utils.is_child_of_process_name("init") or
+                        utils.is_child_of_process_name("systemd"))
         self.assertFalse(utils.is_child_of_process_name("mvo"))
         for e in glob.glob("/proc/[0-9]*"):
             pid = int(e[6:])
